@@ -282,8 +282,17 @@ module YARD
             end
           end
 
-          if @tokens.last && @tokens.last[0] == :symbeg
-            @tokens[-1] = [:symbol, ":" + data, @tokens.last[2]]
+          if token == :symbeg
+            @symbol = [:symbol, data, [lineno, charno]]
+          elsif @symbol
+            case token
+            when :tstring_content
+              @symbol[1] += data
+            when :tstring_end, :const, :ident
+              @symbol[1] += data
+              @tokens << @symbol
+              @symbol = nil
+            end
           elsif @heredoc_state == :started
             @heredoc_tokens << [token, data, [lineno, charno]]
 
